@@ -24,10 +24,10 @@ import java.util.Locale;
 
 import org.videolan.Logger;
 
-class BDGraphicsEnvironment extends GraphicsEnvironment {
+public class BDGraphicsEnvironment extends GraphicsEnvironment {
     private BDGraphicsDevice graphicsDevice;
 
-    BDGraphicsEnvironment() {
+    public BDGraphicsEnvironment() {
         graphicsDevice = new BDGraphicsDevice(this);
     }
 
