@@ -22,8 +22,7 @@ package javax.tv.service.navigation;
 import javax.tv.service.*;
 
 public class ServiceComponentChangeEvent extends ServiceDetailsSIChangeEvent {
-    public ServiceComponentChangeEvent(ServiceDetails details,
-            SIChangeType type, ServiceComponent component) {
+    public ServiceComponentChangeEvent(ServiceDetails details, SIChangeType type, ServiceComponent component) {
         super(details, type, component);
 
         this.component = component;
