@@ -29,53 +29,44 @@ public class FileAttributes {
     public static final int PRIORITY_MEDIUM = 2;
     public static final int PRIORITY_HIGH = 3;
 
-    protected FileAttributes(Date expiration_date,
-            FileAccessPermissions permissions, int priority)
-    {
+    protected FileAttributes(Date expirationDate,
+            FileAccessPermissions permissions, int priority) {
+        this.expirationDate = expirationDate;
         this.permissions = permissions;
         this.priority = priority;
     }
 
-    public Date getExpirationDate()
-    {
-        org.videolan.Logger.unimplemented(FileAttributes.class.getName(), "getExpirationDate");
-        return null;
+    public Date getExpirationDate() {
+        return expirationDate;
     }
 
-    public void setExpirationDate(Date d)
-    {
-        // expiration dates are for losers
+    public void setExpirationDate(Date d) {
+        this.expirationDate = d;
     }
 
-    public FileAccessPermissions getPermissions()
-    {
+    public FileAccessPermissions getPermissions() {
         return permissions;
     }
 
-    public void setPermissions(FileAccessPermissions permissions)
-    {
+    public void setPermissions(FileAccessPermissions permissions) {
         this.permissions = permissions;
     }
 
-    public int getPriority()
-    {
+    public int getPriority() {
         return priority;
     }
 
-    public void setPriority(int priority)
-    {
+    public void setPriority(int priority) {
         this.priority = priority;
     }
 
     public static void setFileAttributes(FileAttributes p, File f)
-            throws IOException
-    {
+            throws IOException {
         org.videolan.Logger.unimplemented(FileAttributes.class.getName(), "setFileAttributes");
         // not implemented
     }
 
-    public static FileAttributes getFileAttributes(File f) throws IOException
-    {
+    public static FileAttributes getFileAttributes(File f) throws IOException {
         boolean r = f.canRead();
         boolean w = f.canWrite();
 
@@ -84,6 +75,12 @@ public class FileAttributes {
         return new FileAttributes(null, permissions, PRIORITY_LOW);
     }
 
+    public String toString() {
+        return this.getClass().getName() + "[priority=" + priority + ",permissions=" +
+            permissions + ",expirationDate=" + expirationDate + "]";
+    }
+
     private FileAccessPermissions permissions;
     private int priority;
+    private Date expirationDate;
 }
