@@ -20,18 +20,20 @@
 package org.dvb.media;
 
 public class AspectRatioChangedEvent extends VideoFormatEvent {
-    public AspectRatioChangedEvent(Object source, int newRatio)
-    {
+    public AspectRatioChangedEvent(Object source, int newRatio) {
         super(source);
-        
+
         this.newRatio = newRatio;
     }
 
-    public int getNewRatio()
-    {
+    public int getNewRatio() {
         return newRatio;
     }
 
-    private int newRatio;
+    public String toString() {
+        return getClass().getName() + "[source=" + source + ",newRatio=" + newRatio + "]";
+    }
+
+    private final int newRatio;
     private static final long serialVersionUID = -897298629574550910L;
 }
