@@ -37,9 +37,9 @@ import javax.media.protocol.DataSource;
 
 import org.bluray.net.BDLocator;
 
-//import org.videolan.media.content.playlist.MediaTimePositionControlImpl;
-import org.videolan.media.content.playlist.OverallGainControlImpl;
-import org.videolan.media.content.playlist.PanningControlImpl;
+import org.videolan.media.content.control.MediaTimePositionControlImpl;
+import org.videolan.media.content.control.OverallGainControlImpl;
+import org.videolan.media.content.control.PanningControlImpl;
 
 import org.videolan.media.content.BDHandler;
 
@@ -59,11 +59,11 @@ public class Handler extends BDHandler {
         if (source.getLocator() == null)
             throw new IncompatibleSourceException();
 
-            try {
-                locator = new BDLocator(source.getLocator().toExternalForm());
-            } catch (org.davic.net.InvalidLocatorException e) {
-                throw new IncompatibleSourceException();
-            }
+        try {
+            locator = new BDLocator(source.getLocator().toExternalForm());
+        } catch (org.davic.net.InvalidLocatorException e) {
+            throw new IncompatibleSourceException();
+        }
     }
 
     public Time getDuration() {
@@ -96,9 +96,11 @@ public class Handler extends BDHandler {
         return null;
     }
 
-    protected ControllerErrorEvent doStop() {
-        return super.doStop();
+    /*
+    protected ControllerErrorEvent doStop(boolean eof) {
+        return super.doStop(eof);
     }
+    */
 
     protected BDLocator getLocator() {
         return locator;
